@@ -2,7 +2,7 @@
  * notify-osd.c - xchat plugin which provides "OSD" like functionality through
  *                libnotify
  *
- * Copyright (C) 2005 David Trowbridge
+ * Copyright (C) 2005-2007 David Trowbridge
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,8 +22,8 @@
 
 #include <config.h>
 #include <libnotify/notify.h>
-#include <libgnome/gnome-i18n.h>
 #include <string.h>
+#include <glib/gi18n.h>
 #include "xchat-plugin.h"
 #include "xg-plugin.h"
 
@@ -197,7 +197,8 @@ xchat_plugin_init (xchat_plugin *plugin_handle, char **plugin_name, char **plugi
 
 	ph = plugin_handle;
 
-	if (notify_init ("Xchat OSD")) {
+	if (notify_init ("XChat-GNOME OSD")) {
+		/* FIXME: multi-head! */
 		GtkIconTheme *theme = gtk_icon_theme_get_default ();
 		notify_icon = gtk_icon_theme_load_icon (theme, "xchat-gnome", 48, 0, NULL);
 
@@ -218,6 +219,16 @@ xchat_plugin_init (xchat_plugin *plugin_handle, char **plugin_name, char **plugi
 int
 xchat_plugin_deinit (void)
 {
+	got_focus_cb (main_window, NULL, NULL);
+
 	notify_uninit ();
+
+	if (notify_icon) {
+		g_object_unref (notify_icon);
+		notify_icon = NULL;
+	}
+
+	ph = NULL;
+
 	return TRUE;
 }
