@@ -18,6 +18,7 @@
 static char RCSID[] = "$Id: tclplugin.c,v 1.59 2005/08/11 02:37:55 mooooooo Exp $";
 
 #include <config.h>
+#include <glib/gi18n.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -37,6 +38,20 @@ static char RCSID[] = "$Id: tclplugin.c,v 1.59 2005/08/11 02:37:55 mooooooo Exp
 #include <unistd.h>
 #endif
 
+#if defined(ENABLE_NLS) && !defined(_)
+#  include <libintl.h>
+#  define _(x) gettext(x)
+#  ifdef gettext_noop
+#    define N_(String) gettext_noop (String)
+#  else
+#    define N_(String) (String)
+#  endif
+#endif
+#if !defined(_)
+#  define N_(String) (String)
+#  define _(x) (x)
+#endif
+
 #include "xchat-plugin.h"
 #include "tclplugin.h"
 #include "printevents.h"
